@@ -7,6 +7,8 @@
 
 #if HAVE_CURSES_H
 #include <curses.h>
+#elif HAVE_NCURSES_CURSES_H
+#include <ncurses/curses.h>
 #endif /* HAVE_CURSES_H */
 
 /* ------------------- */
