@@ -4,6 +4,8 @@
 
 #if HAVE_CURSES_H
 #include <curses.h>
+#elif HAVE_NCURSES_CURSES_H
+#include <ncurses/curses.h>
 #endif /* HAVE_CURSES_H */
 
 #if HAVE_STRING_H
@@ -779,8 +781,7 @@ int kui_term_is_cgdb_key ( int key ) {
 char *
 kui_term_get_ascii_char_sequence_from_key (int key)
 {
-  int i, val;
-  const char *keycode;
+  int i;
 
   if (key < CGDB_KEY_ESC || key >= CGDB_KEY_ERROR)
     return NULL;
