@@ -24,6 +24,8 @@
 
 #if HAVE_CURSES_H
 #include <curses.h>
+#elif HAVE_NCURSES_CURSES_H
+#include <ncurses/curses.h>
 #endif /* HAVE_CURSES_H */
 
 #ifdef HAVE_SYS_TIME_H
@@ -319,7 +321,6 @@ rlctx_send_user_command (char *line)
   int length;
   char *rline_prompt;
   tgdb_request_ptr request_ptr;
-  int i;
 
   if (line == NULL) {
     /* NULL line means rl_callback_read_char received EOF */
