@@ -12,6 +12,8 @@
 /* System Includes */
 #if HAVE_CURSES_H
 #include <curses.h>
+#elif HAVE_NCURSES_CURSES_H
+#include <ncurses/curses.h>
 #endif /* HAVE_CURSES_H */
 
 #if HAVE_SIGNAL_H
