@@ -1,5 +1,5 @@
 
-/* A Bison parser, made by GNU Bison 2.3a+.  */
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
    
@@ -46,7 +46,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.3a+"
+#define YYBISON_VERSION "2.4.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -79,7 +79,7 @@
 /* Copy the first part of user declarations.  */
 
 /* Line 189 of yacc.c  */
-#line 8 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+#line 8 "gdbmi_grammar.y"
 
 #include <string.h>
 #include <stdlib.h>
@@ -107,7 +107,7 @@ void gdbmi_error (gdbmi_pdata_ptr gdbmi_pdata, const char *s)
 
 
 /* Line 189 of yacc.c  */
-#line 111 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.c"
+#line 111 "gdbmi_grammar.c"
 
 /* Enabling traces.  */
 #ifndef YYDEBUG
@@ -130,12 +130,12 @@ void gdbmi_error (gdbmi_pdata_ptr gdbmi_pdata, const char *s)
 /* "%code requires" blocks.  */
 
 /* Line 209 of yacc.c  */
-#line 5 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+#line 5 "gdbmi_grammar.y"
  struct gdbmi_pdata; 
 
 
 /* Line 209 of yacc.c  */
-#line 139 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.c"
+#line 139 "gdbmi_grammar.c"
 
 /* Tokens.  */
 #ifndef YYTOKENTYPE
@@ -191,7 +191,7 @@ typedef union YYSTYPE
 {
 
 /* Line 214 of yacc.c  */
-#line 53 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+#line 53 "gdbmi_grammar.y"
 
   struct gdbmi_output *u_output;
   struct gdbmi_oob_record *u_oob_record;
@@ -212,7 +212,7 @@ typedef union YYSTYPE
 
 
 /* Line 214 of yacc.c  */
-#line 216 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.c"
+#line 216 "gdbmi_grammar.c"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
@@ -248,7 +248,7 @@ void yypstate_delete ();
 
 
 /* Line 264 of yacc.c  */
-#line 252 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.c"
+#line 252 "gdbmi_grammar.c"
 
 #ifdef short
 # undef short
@@ -1214,7 +1214,6 @@ struct yypstate
     int yynew;
   };
 
-
 /* Initialize the parser data structure.  */
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
@@ -1318,7 +1317,6 @@ YYSTYPE yylval;
   yytoken = 0;
   yyss = yyssa;
   yyvs = yyvsa;
-
   yystacksize = YYINITDEPTH;
 
   YYDPRINTF ((stderr, "Starting parse\n"));
@@ -1441,7 +1439,6 @@ yybackup:
           goto yypushreturn;
         }
       yyps->yynew = 0;
-
 yyread_pushed_token:
       YYDPRINTF ((stderr, "Reading a token: "));
       yychar = yypushed_char;
@@ -1524,8 +1521,8 @@ yyreduce:
     {
         case 2:
 
-/* Line 1464 of yacc.c  */
-#line 96 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 96 "gdbmi_grammar.y"
     {
   gdbmi_pdata->tree = (yyvsp[(1) - (1)].u_output);
 }
@@ -1533,8 +1530,8 @@ yyreduce:
 
   case 3:
 
-/* Line 1464 of yacc.c  */
-#line 100 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 100 "gdbmi_grammar.y"
     {
   gdbmi_pdata->tree = append_gdbmi_output (gdbmi_pdata->tree, (yyvsp[(2) - (2)].u_output));
   gdbmi_pdata->parsed_one = 1;
@@ -1543,8 +1540,8 @@ yyreduce:
 
   case 4:
 
-/* Line 1464 of yacc.c  */
-#line 105 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 105 "gdbmi_grammar.y"
     { 
   (yyval.u_output) = create_gdbmi_output ();
   (yyval.u_output)->oob_record = (yyvsp[(1) - (6)].u_oob_record);
@@ -1559,8 +1556,8 @@ yyreduce:
 
   case 5:
 
-/* Line 1464 of yacc.c  */
-#line 116 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 116 "gdbmi_grammar.y"
     {
   (yyval.u_oob_record) = NULL;
 }
@@ -1568,8 +1565,8 @@ yyreduce:
 
   case 6:
 
-/* Line 1464 of yacc.c  */
-#line 120 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 120 "gdbmi_grammar.y"
     {
   (yyval.u_oob_record) = append_gdbmi_oob_record ((yyvsp[(1) - (3)].u_oob_record), (yyvsp[(2) - (3)].u_oob_record));
 }
@@ -1577,8 +1574,8 @@ yyreduce:
 
   case 7:
 
-/* Line 1464 of yacc.c  */
-#line 124 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 124 "gdbmi_grammar.y"
     {
   (yyval.u_result_record) = NULL;
 }
@@ -1586,8 +1583,8 @@ yyreduce:
 
   case 8:
 
-/* Line 1464 of yacc.c  */
-#line 128 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 128 "gdbmi_grammar.y"
     {
   (yyval.u_result_record) = (yyvsp[(1) - (2)].u_result_record);
 }
@@ -1595,8 +1592,8 @@ yyreduce:
 
   case 9:
 
-/* Line 1464 of yacc.c  */
-#line 132 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 132 "gdbmi_grammar.y"
     {
   (yyval.u_result_record) = create_gdbmi_result_record ();
   (yyval.u_result_record)->token = (yyvsp[(1) - (3)].u_token);
@@ -1607,8 +1604,8 @@ yyreduce:
 
   case 10:
 
-/* Line 1464 of yacc.c  */
-#line 139 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 139 "gdbmi_grammar.y"
     {
   (yyval.u_result_record) = create_gdbmi_result_record ();
   (yyval.u_result_record)->token = (yyvsp[(1) - (5)].u_token);
@@ -1619,8 +1616,8 @@ yyreduce:
 
   case 11:
 
-/* Line 1464 of yacc.c  */
-#line 146 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 146 "gdbmi_grammar.y"
     {
   (yyval.u_oob_record) = create_gdbmi_oob_record();
   (yyval.u_oob_record)->record = GDBMI_ASYNC;
@@ -1630,8 +1627,8 @@ yyreduce:
 
   case 12:
 
-/* Line 1464 of yacc.c  */
-#line 152 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 152 "gdbmi_grammar.y"
     {
   (yyval.u_oob_record) = create_gdbmi_oob_record();
   (yyval.u_oob_record)->record = GDBMI_STREAM;
@@ -1641,8 +1638,8 @@ yyreduce:
 
   case 13:
 
-/* Line 1464 of yacc.c  */
-#line 158 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 158 "gdbmi_grammar.y"
     {
   (yyval.u_async_record) = create_gdbmi_async_record ();
   (yyval.u_async_record)->token = (yyvsp[(1) - (3)].u_token);
@@ -1653,8 +1650,8 @@ yyreduce:
 
   case 14:
 
-/* Line 1464 of yacc.c  */
-#line 165 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 165 "gdbmi_grammar.y"
     {
   (yyval.u_async_record) = create_gdbmi_async_record ();
   (yyval.u_async_record)->token = (yyvsp[(1) - (5)].u_token);
@@ -1666,8 +1663,8 @@ yyreduce:
 
   case 15:
 
-/* Line 1464 of yacc.c  */
-#line 173 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 173 "gdbmi_grammar.y"
     {
   (yyval.u_async_record_choice) = GDBMI_EXEC;
 }
@@ -1675,8 +1672,8 @@ yyreduce:
 
   case 16:
 
-/* Line 1464 of yacc.c  */
-#line 177 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 177 "gdbmi_grammar.y"
     {
   (yyval.u_async_record_choice) = GDBMI_STATUS;
 }
@@ -1684,8 +1681,8 @@ yyreduce:
 
   case 17:
 
-/* Line 1464 of yacc.c  */
-#line 181 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 181 "gdbmi_grammar.y"
     {
   (yyval.u_async_record_choice) = GDBMI_NOTIFY;	
 }
@@ -1693,8 +1690,8 @@ yyreduce:
 
   case 18:
 
-/* Line 1464 of yacc.c  */
-#line 185 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 185 "gdbmi_grammar.y"
     {
   if (strcmp ("done", gdbmi_text) == 0)
     (yyval.u_result_class) = GDBMI_DONE;
@@ -1713,8 +1710,8 @@ yyreduce:
 
   case 19:
 
-/* Line 1464 of yacc.c  */
-#line 200 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 200 "gdbmi_grammar.y"
     {
   if (strcmp ("stopped", gdbmi_text) != 0)
     gdbmi_error (gdbmi_pdata,  "Syntax error, expected 'stopped'" );
@@ -1725,8 +1722,8 @@ yyreduce:
 
   case 20:
 
-/* Line 1464 of yacc.c  */
-#line 207 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 207 "gdbmi_grammar.y"
     {
   (yyval.u_result) = append_gdbmi_result (NULL, (yyvsp[(1) - (1)].u_result));	
 }
@@ -1734,8 +1731,8 @@ yyreduce:
 
   case 21:
 
-/* Line 1464 of yacc.c  */
-#line 211 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 211 "gdbmi_grammar.y"
     {
   (yyval.u_result) = append_gdbmi_result ((yyvsp[(1) - (3)].u_result), (yyvsp[(3) - (3)].u_result));
 }
@@ -1743,8 +1740,8 @@ yyreduce:
 
   case 22:
 
-/* Line 1464 of yacc.c  */
-#line 215 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 215 "gdbmi_grammar.y"
     {
   (yyval.u_result) = create_gdbmi_result ();
   (yyval.u_result)->variable = (yyvsp[(1) - (3)].u_variable);
@@ -1754,8 +1751,8 @@ yyreduce:
 
   case 23:
 
-/* Line 1464 of yacc.c  */
-#line 221 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 221 "gdbmi_grammar.y"
     {
   (yyval.u_variable) = strdup (gdbmi_text);
 }
@@ -1763,8 +1760,8 @@ yyreduce:
 
   case 24:
 
-/* Line 1464 of yacc.c  */
-#line 225 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 225 "gdbmi_grammar.y"
     {
   (yyval.u_value) = append_gdbmi_value (NULL, (yyvsp[(1) - (1)].u_value));	
 }
@@ -1772,8 +1769,8 @@ yyreduce:
 
   case 25:
 
-/* Line 1464 of yacc.c  */
-#line 229 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 229 "gdbmi_grammar.y"
     {
   (yyval.u_value) = append_gdbmi_value ((yyvsp[(1) - (3)].u_value), (yyvsp[(3) - (3)].u_value)); 
 }
@@ -1781,8 +1778,8 @@ yyreduce:
 
   case 26:
 
-/* Line 1464 of yacc.c  */
-#line 233 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 233 "gdbmi_grammar.y"
     {
   (yyval.u_value) = create_gdbmi_value ();
   (yyval.u_value)->value_choice = GDBMI_CSTRING;
@@ -1792,8 +1789,8 @@ yyreduce:
 
   case 27:
 
-/* Line 1464 of yacc.c  */
-#line 239 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 239 "gdbmi_grammar.y"
     {
   (yyval.u_value) = create_gdbmi_value ();
   (yyval.u_value)->value_choice = GDBMI_TUPLE;
@@ -1803,8 +1800,8 @@ yyreduce:
 
   case 28:
 
-/* Line 1464 of yacc.c  */
-#line 245 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 245 "gdbmi_grammar.y"
     {
   (yyval.u_value) = create_gdbmi_value ();
   (yyval.u_value)->value_choice = GDBMI_LIST;
@@ -1814,8 +1811,8 @@ yyreduce:
 
   case 29:
 
-/* Line 1464 of yacc.c  */
-#line 251 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 251 "gdbmi_grammar.y"
     {
   (yyval.u_tuple) = NULL;
 }
@@ -1823,8 +1820,8 @@ yyreduce:
 
   case 30:
 
-/* Line 1464 of yacc.c  */
-#line 255 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 255 "gdbmi_grammar.y"
     {
   (yyval.u_tuple) = create_gdbmi_tuple ();
   (yyval.u_tuple)->result = (yyvsp[(2) - (3)].u_result);
@@ -1833,8 +1830,8 @@ yyreduce:
 
   case 31:
 
-/* Line 1464 of yacc.c  */
-#line 260 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 260 "gdbmi_grammar.y"
     {
   (yyval.u_list) = NULL;
 }
@@ -1842,8 +1839,8 @@ yyreduce:
 
   case 32:
 
-/* Line 1464 of yacc.c  */
-#line 264 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 264 "gdbmi_grammar.y"
     {
   (yyval.u_list) = create_gdbmi_list ();
   (yyval.u_list)->list_choice = GDBMI_VALUE;
@@ -1853,8 +1850,8 @@ yyreduce:
 
   case 33:
 
-/* Line 1464 of yacc.c  */
-#line 270 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 270 "gdbmi_grammar.y"
     {
   (yyval.u_list) = create_gdbmi_list ();
   (yyval.u_list)->list_choice = GDBMI_RESULT;
@@ -1864,8 +1861,8 @@ yyreduce:
 
   case 34:
 
-/* Line 1464 of yacc.c  */
-#line 276 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 276 "gdbmi_grammar.y"
     {
   (yyval.u_stream_record) = create_gdbmi_stream_record ();
   (yyval.u_stream_record)->stream_record = (yyvsp[(1) - (2)].u_stream_record_choice);
@@ -1875,8 +1872,8 @@ yyreduce:
 
   case 35:
 
-/* Line 1464 of yacc.c  */
-#line 282 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 282 "gdbmi_grammar.y"
     {
   (yyval.u_stream_record_choice) = GDBMI_CONSOLE;
 }
@@ -1884,8 +1881,8 @@ yyreduce:
 
   case 36:
 
-/* Line 1464 of yacc.c  */
-#line 286 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 286 "gdbmi_grammar.y"
     {
   (yyval.u_stream_record_choice) = GDBMI_TARGET;
 }
@@ -1893,8 +1890,8 @@ yyreduce:
 
   case 37:
 
-/* Line 1464 of yacc.c  */
-#line 290 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 290 "gdbmi_grammar.y"
     {
   (yyval.u_stream_record_choice) = GDBMI_LOG;
 }
@@ -1902,8 +1899,8 @@ yyreduce:
 
   case 38:
 
-/* Line 1464 of yacc.c  */
-#line 294 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 294 "gdbmi_grammar.y"
     {
   (yyval.u_token) = -1;	
 }
@@ -1911,8 +1908,8 @@ yyreduce:
 
   case 39:
 
-/* Line 1464 of yacc.c  */
-#line 298 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 298 "gdbmi_grammar.y"
     {
   (yyval.u_token) = (yyvsp[(1) - (1)].u_token);
 }
@@ -1920,8 +1917,8 @@ yyreduce:
 
   case 40:
 
-/* Line 1464 of yacc.c  */
-#line 302 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1455 of yacc.c  */
+#line 302 "gdbmi_grammar.y"
     {
   (yyval.u_token) = atol (gdbmi_text);
 }
@@ -1929,8 +1926,8 @@ yyreduce:
 
 
 
-/* Line 1464 of yacc.c  */
-#line 1934 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.c"
+/* Line 1455 of yacc.c  */
+#line 1931 "gdbmi_grammar.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
