@@ -1,5 +1,5 @@
 
-/* A Bison parser, made by GNU Bison 2.3a+.  */
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton interface for Bison's Yacc-like parsers in C
    
@@ -34,13 +34,13 @@
 
 /* "%code requires" blocks.  */
 
-/* Line 1685 of yacc.c  */
-#line 5 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1676 of yacc.c  */
+#line 5 "gdbmi_grammar.y"
  struct gdbmi_pdata; 
 
 
-/* Line 1685 of yacc.c  */
-#line 44 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.h"
+/* Line 1676 of yacc.c  */
+#line 44 "gdbmi_grammar.h"
 
 /* Tokens.  */
 #ifndef YYTOKENTYPE
@@ -95,8 +95,8 @@
 typedef union YYSTYPE
 {
 
-/* Line 1685 of yacc.c  */
-#line 53 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.y"
+/* Line 1676 of yacc.c  */
+#line 53 "gdbmi_grammar.y"
 
   struct gdbmi_output *u_output;
   struct gdbmi_oob_record *u_oob_record;
@@ -116,8 +116,8 @@ typedef union YYSTYPE
 
 
 
-/* Line 1685 of yacc.c  */
-#line 121 "../../../../cgdb/lib/gdbmi/src/gdbmi_grammar.h"
+/* Line 1676 of yacc.c  */
+#line 121 "gdbmi_grammar.h"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
